==> openwebmail-2.32.tgz: htdocs/openwebmail/javascript/htmlarea.openwebmail/popups/sr/htmlarea-lang.js <==
// I18N constants

// Translation Note
// 1. translate the left  side of fontname, font size and formatblock
// 2. translate the right side of tooltips

HTMLArea.I18N = {
	fontname: {
		"Arial":           'arial,helvetica,sans-serif',
		"Courier New":     'courier new,courier,monospace',
		"Georgia":         'georgia,times new roman,times,serif',
		"Tahoma":          'tahoma,arial,helvetica,sans-serif',
		"Times New Roman": 'times new roman,times,serif',
		"Verdana":         'verdana,arial,helvetica,sans-serif',
		"impact":          'impact',
		"WingDings":       'wingdings'
	},

	fontsize: {
		"1 (8 taaka)":  "1",
		"2 (10 taaka)": "2",
		"3 (12 taaka)": "3",
		"4 (14 taaka)": "4",
		"5 (18 taaka)": "5",
		"6 (24 taaka)": "6",
		"7 (36 taaka)": "7"
	},

	formatblock: {
		"Zaglavlje 1": "h1",
		"Zaglavlje 2": "h2",
		"Zaglavlje 3": "h3",
		"Zaglavlje 4": "h4",
		"Zaglavlje 5": "h5",
		"Zaglavlje 6": "h6",
		"Paragraf": "p",
		"Adresa": "address",
		"Formatirano": "pre"
	},

	tooltips: {
		bold:           "Podebljan",
		italic:         "Kurziv",
		underline:      "Podvuen",
		strikethrough:  "Precrtan",
		subscript:      "Indeksna lista",
		superscript:    "Indeks",
		justifyleft:    "Poravnavanje ulevo",
		justifycenter:  "Poravnavanje po sredini",
		justifyright:   "Poravnavanje udesno",
		justifyfull:    "Poravnavanje po obe ivice",
		insertorderedlist:    "Ureena lista",
		insertunorderedlist:  "Neureena lista",
		outdent:        "Smanji razmak",
		indent:         "Uveaj razmak",
		forecolor:      "Boja fonta",
		hilitecolor:    "Boja pozadine",
		horizontalrule: "Horizontal Rule",
		createlink:     "Ubaci vezu",
		insertimage:    "Ubaci sliku",
		insertsound:    "Ubaci zvuk",
		inserttable:    "Ubaci tabelu",
		htmlmode:       "Prikai izvorni HTML",
		popupeditor:    "Uveaj editor",
		about:          "O editoru",
		showhelp:       "Pomo u korienju editora",
		textindicator:  "Trenutni stil",
		undo:           "Undoes your last action",
		redo:           "Redoes your last action",
		cut:            "Cut selection",
		copy:           "Copy selection",
		paste:          "Paste from clipboard"
	},

	buttons: {
		"ok":           "OK",
		"cancel":       "Cancel"
	},

	msg: {
		"Path":         "Path",
		"TEXT_MODE":    "You are in TEXT MODE.  Use the [<>] button to switch back to WYSIWIG."
	}
};

==> openwebmail-2.51p2.tgz: htdocs/openwebmail/javascript/htmlarea.openwebmail/popups/sr/htmlarea-lang.js <==
// I18N constants

// Translation Note
// 1. translate the left  side of fontname, font size and formatblock
// 2. translate the right side of tooltips

HTMLArea.I18N = {
	fontname: {
		"Arial":           'arial,helvetica,sans-serif',
		"Courier New":     'courier new,courier,monospace',
		"Georgia":         'georgia,times new roman,times,serif',
		"Tahoma":          'tahoma,arial,helvetica,sans-serif',
		"Times New Roman": 'times new roman,times,serif',
		"Verdana":         'verdana,arial,helvetica,sans-serif',
		"impact":          'impact',
		"WingDings":       'wingdings'
	},

	fontsize: {
		"1 (8 taaka)":  "1",
		"2 (10 taaka)": "2",
		"3 (12 taaka)": "3",
		"4 (14 taaka)": "4",
		"5 (18 taaka)": "5",
		"6 (24 taaka)": "6",
		"7 (36 taaka)": "7"
	},

	formatblock: {
		"Zaglavlje 1": "h1",
		"Zaglavlje 2": "h2",
		"Zaglavlje 3": "h3",
		"Zaglavlje 4": "h4",
		"Zaglavlje 5": "h5",
		"Zaglavlje 6": "h6",
		"Paragraf": "p",
		"Adresa": "address",
		"Formatirano": "pre"
	},

	tooltips: {
		bold:           "Podebljan",
		italic:         "Kurziv",
		underline:      "Podvuen",
		strikethrough:  "Precrtan",
		subscript:      "Indeksna lista",
		superscript:    "Indeks",
		justifyleft:    "Poravnavanje ulevo",
		justifycenter:  "Poravnavanje po sredini",
		justifyright:   "Poravnavanje udesno",
		justifyfull:    "Poravnavanje po obe ivice",
		insertorderedlist:    "Ureena lista",
		insertunorderedlist:  "Neureena lista",
		outdent:        "Smanji razmak",
		indent:         "Uveaj razmak",
		forecolor:      "Boja fonta",
		hilitecolor:    "Boja pozadine",
		inserthorizontalrule: "Horizontalna linija",
		createlink:     "Ubaci vezu",
		insertimage:    "Ubaci sliku",
		insertsound:    "Ubaci zvuk",
		inserttable:    "Ubaci tabelu",
		htmlmode:       "Prikai izvorni HTML",
		popupeditor:    "Uveaj editor",
		about:          "O editoru",
		showhelp:       "Pomo u korienju editora",
		textindicator:  "Trenutni stil",
		undo:           "Ponitavanje poslednje promene",
		redo:           "Vrati ponitenu promenu",
		cut:            "Iseci izbor",
		copy:           "Kopiraj izbor",
		paste:          "Nalepi izbor"
	},

	buttons: {
		"ok":           "U redu",
		"cancel":       "Otkai"
	},

	msg: {
		"Path":         "Putanja",
		"TEXT_MODE":    "Nalazite se u TEKST MODU.  Koristite dugme [<>] da se vratite u WYSIWIG."
	}
};
